@@ -1,11 +1,12 @@
-import cPickle
-import gtk, gobject
-import time
-import logging
-import deskbar.interfaces.Action
 from deskbar import HISTORY_FILE
-from gettext import gettext as _
 from deskbar.core.Categories import CATEGORIES
+from gettext import gettext as _
+import cPickle
+import deskbar.interfaces.Action
+import gobject
+import gtk
+import logging
+import time
 
 LOGGER = logging.getLogger(__name__)
 
@@ -150,7 +151,7 @@ class DeskbarHistory (gtk.ListStore) :
         """
         save = []
         for timestamp, text, action in self:
-            if action.__class__ != ChooseFromHistoryAction:
+            if isinstance(action, ChooseFromHistoryAction):
                 save.append((timestamp, text, action))
         
         try:
@@ -180,7 +181,7 @@ class DeskbarHistory (gtk.ListStore) :
         """
         assert text != None and action != None
         
-        if action.__class__ == ChooseFromHistoryAction:
+        if isinstance(action, ChooseFromHistoryAction):
             return
         if action.skip_history():
             self.reset()
