@@ -1,17 +1,16 @@
 import deskbar.interfaces.Action
 from gettext import gettext as _
 from deskbar.core.Utils import url_show
-from os.path import exists
 
 class ShowUrlAction(deskbar.interfaces.Action):
+    """
+    Open an arbitrary URL
+    """
     
     def __init__(self, name, url):
         deskbar.interfaces.Action.__init__(self, name)
         self._url = url
-        
-    def is_valid(self):
-        return exists(self._url)
-        
+    
     def get_icon(self):
         if self._url.startswith("http") or self._url.startswith("ftp"):
             return "stock_internet"
@@ -25,4 +24,7 @@ class ShowUrlAction(deskbar.interfaces.Action):
         return _("Open %s") % "<b>%(name)s</b>" 
     
     def activate(self, text=None):
-        url_show(self._url)
\ No newline at end of file
+        url_show(self._url)
+        
+    def get_tooltip(self, text=None):
+        return self._url
\ No newline at end of file
