@@ -19,31 +19,29 @@ LOGGER = logging.getLogger(__name__)
 
 GCONF_DELICIOUS_USER  = GconfStore.GCONF_DIR+"/desklicious/user"
 
-DEFAULT_QUERY_TAG = 'http://feeds.delicious.com/rss/%s/%s'
-
+DEFAULT_QUERY_TAG = 'http://del.icio.us/rss/%s/%s'
+QUERY_DELAY = 1
 HANDLERS = ["DeliciousHandler"]
 
 class DeliciousAction(ShowUrlAction):
     
-    def __init__(self, name, url, tags):
+    def __init__(self, name, url, tags=None):
+        """
+        @param tags: Is ignored since 2.23.1,
+        just there for backwards compatibility 
+        """
         ShowUrlAction.__init__(self, name, url)
-        self.tags = tags
         
     def get_verb(self):
-        return "<b>%(name)s</b>\n<span size='small' foreground='grey'>%(tags)s</span>"
-    
-    def get_name(self, text=None):
-        return {
-            "name": self._name,
-            "tags": ' '.join(self.tags),
-        }
+        return "<b>%(name)s</b>"
         
 class DeliciousMatch(deskbar.interfaces.Match):
     def __init__(self, url=None, tags=None, author=None, **args):
         deskbar.interfaces.Match.__init__ (self, icon="delicious.png", **args)
         self.url = url
         self.author = author
-        self.add_action( DeliciousAction(self.get_name(), self.url, tags) )
+        self.set_snippet(' '.join(tags))
+        self.add_action( DeliciousAction(self.get_name(), self.url) )
 
     def get_hash(self):
         return self.url
@@ -66,9 +64,11 @@ class DeliciousHandler(deskbar.interfaces.Module):
         tag = self._bad_chars_pattern.sub(' ', tag)
         
         #The queryyyyYyyYy :)
-        LOGGER.info( "Asking del.icio.us tags for %s" % tag )
+        LOGGER.info( "Asking del.icio.us tags for %s", tag )
         posts = self._delicious.get_posts_by_tag(tag)
 
+        # TODO: Missing
+        #self.check_query_changed (timeout=QUERY_DELAY)
         LOGGER.info('Returning del.icio.us result')
         self.set_priority_for_matches( posts )
         self._emit_query_ready(tag, posts )
@@ -133,63 +133,43 @@ class DeliciousTagQueryEngine:
         if self._user == None:
             return []
         
-        posts = []
+        posts=[]
         #Get the info from del.icio.us and parse
         url = DEFAULT_QUERY_TAG % (urllib.quote_plus(self._user), urllib.quote_plus(tag))
         
         LOGGER.debug("Opening URL %s", url)
-        stream = None
         try:
-            stream = urllib.urlopen(url, proxies=deskbar.core.Utils.get_proxy())
-        except IOError, msg:
-            LOGGER.error("Could not open URL %s: %s, %s", url, msg[0], msg[1])
-            return []
-                
-        try:
-            dom = xml.dom.minidom.parse(stream)
-        except ExpatError, e:
-            LOGGER.exception(e)
-            return []
-        
-        if stream != None:
+            try:
+                stream = urllib.urlopen(url, proxies=deskbar.core.Utils.get_proxy())
+                dom = xml.dom.minidom.parse(stream)
+            except IOError, msg:
+                LOGGER.error("Could not open URL %s: %s, %s", url, msg[0], msg[1])
+            except ExpatError, e:
+                LOGGER.exception(e)
+        finally:
             stream.close()
         
         #And return the results
         try:
             try:
                 for item in dom.getElementsByTagName("item"):
-                    title_nodes = item.getElementsByTagName("title")
-                    url_nodes = item.getElementsByTagName("link")
+                    title_node = item.getElementsByTagName("title")[0]
+                    url_node = item.getElementsByTagName("link")[0]
+                    subject_node = item.getElementsByTagName("dc:subject")[0]
+                    creator_node = item.getElementsByTagName("dc:creator")[0]
                     
-                    # Check if we have expected content at all
-                    if len(title_nodes) == 0 or len(url_nodes) == 0:
-                        return []
-                    
-                    item_title = title_nodes[0].firstChild.nodeValue
-                    item_url = url_nodes[0].firstChild.nodeValue
-                    
-                    # by default we have no tags
-                    tags = []
-                    subject_nodes = item.getElementsByTagName("dc:subject")
-                    if len(subject_nodes) > 0:
-                        subject_node = subject_nodes[0]
-                        # There might be no tags
-                        if (subject_node.hasChildNodes()):
-                            tags = subject_node.firstChild.nodeValue.split(" ")
-                    
-                    creator_nodes = item.getElementsByTagName("dc:creator")
-                    if len(creator_nodes) > 0: 
-                        creator_node = creator_nodes[0]
-                        creator = creator_node.firstChild.nodeValue
+                    # There might be no tags
+                    if (subject_node.hasChildNodes()):
+                        tags = subject_node.firstChild.nodeValue.split(" ")
                     else:
-                        creator = self._user
+                        tags = []
                     
                     posts.append(
                         DeliciousMatch(
-                            name=item_title,
-                            url=item_url,
+                            name=title_node.firstChild.nodeValue,
+                            url=url_node.firstChild.nodeValue,
                             tags=tags,
-                            author=creator,
+                            author=creator_node.firstChild.nodeValue,
                             category="web"))
             except DOMException, e:
                 LOGGER.exception(e)
