@@ -1,16 +1,16 @@
-import re
-import dbus
 from dbus.mainloop.glib import DBusGMainLoop
-from deskbar.defs import VERSION
 from deskbar.core.Utils import load_icon
+from deskbar.defs import VERSION
+from deskbar.handlers.actions.CopyToClipboardAction import CopyToClipboardAction
+from gettext import gettext as _
+import dbus
 import deskbar.interfaces.Action
 import deskbar.interfaces.Match
 import deskbar.interfaces.Module
-from deskbar.handlers.actions.CopyToClipboardAction import CopyToClipboardAction
 import gtk
-from gettext import gettext as _
 import logging
-import subprocess
+import os
+import re
 
 LOGGER = logging.getLogger(__name__)
 
@@ -180,7 +180,7 @@ class TomboyNotesModule (deskbar.interfaces.Module):
                 LOGGER.exception(e)
                 return
     
-    def handle_dbus_error(self, e): print e
+    def handle_dbus_error(self, e): LOGGER.error(e)
     
     def query(self, text):
         if len(text) >= 3:
@@ -242,14 +242,9 @@ def tomboy_installed():
 # If we use DBus, it will wake up Tomboy even if 
 # this module isn't enabled.
 def get_tomboy_version():
-    try:
-        command = subprocess.Popen("tomboy --version", shell=True,
-                                   stdout=subprocess.PIPE).stdout
-        read = command.read()
-        command.close()
-    except OSError, e:
-        LOGGER.exception(e)
-        return '0.0.0'
+    command = os.popen("tomboy --version")
+    read = command.read()
+    command.close()
     
     line_regexp = re.compile( 'Version (\d+?)\.(\d+?)\.(\d+?)', re.IGNORECASE )
     results_list = line_regexp.findall( read )
